@@ -625,6 +625,9 @@ int RdpSession::clientContextStart(rdpContext *context)
     if (!freerdp_settings_set_bool(settings, FreeRDP_ExtSecurity, preferences->securityEXT())) {
         return -1;
     }
+    if (!freerdp_settings_set_bool(settings, FreeRDP_ConsoleSession, preferences->consoleMode())) {
+        return -1;
+    }
 
     if (!preferences->authPkgList().isEmpty()
         && !freerdp_settings_set_string(settings, FreeRDP_AuthenticationPackageList, preferences->authPkgList().toUtf8().data())) {
@@ -773,7 +776,7 @@ BOOL RdpSession::endPaint(rdpContext *context)
     }
 
     auto rect = QRect{invalid->x, invalid->y, invalid->w, invalid->h};
-    Q_EMIT session->rectangleUpdated(rect);
+    Q_EMIT session->rectangleUpdated(rect, session->m_size);
     return true;
 }
 
