@@ -111,7 +111,7 @@ QSize RdpView::sizeHint() const
     return m_session->size() / devicePixelRatio();
 }
 
-void RdpView::startQuitting()
+void RdpView::startQuittingConnection()
 {
     if (m_quitting) {
         return; // ignore repeated triggers
@@ -136,7 +136,7 @@ bool RdpView::isQuitting()
     return m_quitting;
 }
 
-bool RdpView::start()
+bool RdpView::startConnection()
 {
     m_session = std::make_unique<RdpSession>(this);
     m_session->setHostPreferences(m_hostPreferences.get());
@@ -391,6 +391,11 @@ bool RdpView::supportsViewOnly() const
     return true;
 }
 
+bool RdpView::supportsClipboardSharing() const
+{
+    return true;
+}
+
 void RdpView::showLocalCursor(LocalCursorState state)
 {
     RemoteView::showLocalCursor(state);
@@ -492,10 +497,13 @@ void RdpView::handleWheelEvent(QWheelEvent *event)
     }
 }
 
-void RdpView::onRectangleUpdated(const QRect &rect)
+void RdpView::onRectangleUpdated(const QRect &remoteRect, const QSize &remoteSize)
 {
-    m_pendingRectangle = rect;
-    update();
+    // convert remoteRect based on remoteSize to local widget size()
+    auto ratio = (qreal)size().width() / remoteSize.width();
+    auto destRect =
+        QRect{qFloor(remoteRect.x() * ratio), qFloor(remoteRect.y() * ratio), qCeil(remoteRect.width() * ratio), qCeil(remoteRect.height() * ratio)};
+    update(destRect);
 }
 
 void RdpView::handleLocalClipboardChanged(const QMimeData *data)
@@ -503,4 +511,4 @@ void RdpView::handleLocalClipboardChanged(const QMimeData *data)
     if (m_session) {
         m_session->sendClipboard(data);
     }
-}
\ No newline at end of file
+}
